@@ -23,6 +23,7 @@
 #include <functional>
 #include <map>
 #include <memory>
+#include <optional>
 #include <string>
 #include <type_traits>
 #include <utility>
@@ -34,10 +35,9 @@
 #include "absl/strings/str_cat.h"
 #include "absl/strings/str_join.h"
 #include "absl/strings/string_view.h"
-#include "absl/types/optional.h"
 #include "src/core/client_channel/client_channel_internal.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/lib/channel/channel_args.h"
-#include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/debug/trace.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/lib/iomgr/pollset_set.h"
@@ -197,7 +197,7 @@ class XdsClusterManagerLb final : public LoadBalancingPolicy {
     grpc_connectivity_state connectivity_state_ = GRPC_CHANNEL_CONNECTING;
 
     // States for delayed removal.
-    absl::optional<EventEngine::TaskHandle> delayed_removal_timer_handle_;
+    std::optional<EventEngine::TaskHandle> delayed_removal_timer_handle_;
     bool shutdown_ = false;
   };
 
@@ -260,11 +260,11 @@ void XdsClusterManagerLb::ShutdownLocked() {
 }
 
 void XdsClusterManagerLb::ExitIdleLocked() {
-  for (auto& p : children_) p.second->ExitIdleLocked();
+  for (auto& [_, child] : children_) child->ExitIdleLocked();
 }
 
 void XdsClusterManagerLb::ResetBackoffLocked() {
-  for (auto& p : children_) p.second->ResetBackoffLocked();
+  for (auto& [_, child] : children_) child->ResetBackoffLocked();
 }
 
 absl::Status XdsClusterManagerLb::UpdateLocked(UpdateArgs args) {
@@ -275,18 +275,15 @@ absl::Status XdsClusterManagerLb::UpdateLocked(UpdateArgs args) {
   // Update config.
   config_ = args.config.TakeAsSubclass<XdsClusterManagerLbConfig>();
   // Deactivate the children not in the new config.
-  for (const auto& p : children_) {
-    const std::string& name = p.first;
-    ClusterChild* child = p.second.get();
+  for (const auto& [name, child] : children_) {
     if (config_->cluster_map().find(name) == config_->cluster_map().end()) {
       child->DeactivateLocked();
     }
   }
   // Add or update the children in the new config.
   std::vector<std::string> errors;
-  for (const auto& p : config_->cluster_map()) {
-    const std::string& name = p.first;
-    const RefCountedPtr<LoadBalancingPolicy::Config>& config = p.second.config;
+  for (const auto& [name, cluster] : config_->cluster_map()) {
+    const RefCountedPtr<LoadBalancingPolicy::Config>& config = cluster.config;
     auto& child = children_[name];
     if (child == nullptr) {
       child = MakeOrphanable<ClusterChild>(
@@ -322,9 +319,7 @@ void XdsClusterManagerLb::UpdateStateLocked() {
   size_t num_ready = 0;
   size_t num_connecting = 0;
   size_t num_idle = 0;
-  for (const auto& p : children_) {
-    const auto& child_name = p.first;
-    const ClusterChild* child = p.second.get();
+  for (const auto& [child_name, child] : children_) {
     // Skip the children that are not in the latest update.
     if (config_->cluster_map().find(child_name) ==
         config_->cluster_map().end()) {
@@ -365,8 +360,7 @@ void XdsClusterManagerLb::UpdateStateLocked() {
       << "[xds_cluster_manager_lb " << this << "] connectivity changed to "
       << ConnectivityStateName(connectivity_state);
   ClusterPicker::ClusterMap cluster_map;
-  for (const auto& p : config_->cluster_map()) {
-    const std::string& cluster_name = p.first;
+  for (const auto& [cluster_name, _] : config_->cluster_map()) {
     RefCountedPtr<SubchannelPicker>& child_picker = cluster_map[cluster_name];
     child_picker = children_[cluster_name]->picker();
     if (child_picker == nullptr) {
@@ -504,14 +498,12 @@ void XdsClusterManagerLb::ClusterChild::DeactivateLocked() {
           ->RunAfter(
               kChildRetentionInterval,
               [self = Ref(DEBUG_LOCATION, "ClusterChild+timer")]() mutable {
-                ApplicationCallbackExecCtx application_exec_ctx;
                 ExecCtx exec_ctx;
                 auto* self_ptr = self.get();  // Avoid use-after-move problem.
                 self_ptr->xds_cluster_manager_policy_->work_serializer()->Run(
                     [self = std::move(self)]() {
                       self->OnDelayedRemovalTimerLocked();
-                    },
-                    DEBUG_LOCATION);
+                    });
               });
 }
 
