@@ -87,7 +87,7 @@ const grpc_channel_filter test_filter = {
     GRPC_UNIQUE_TYPE_NAME_HERE("zzzzzz_filter_init_fails")};
 
 void RegisterFilter(grpc_channel_stack_type type) {
-  CoreConfiguration::RegisterBuilder(
+  CoreConfiguration::RegisterEphemeralBuilder(
       [type](CoreConfiguration::Builder* builder) {
         builder->channel_init()->RegisterFilter(type, &test_filter);
       });
@@ -95,10 +95,9 @@ void RegisterFilter(grpc_channel_stack_type type) {
 
 CORE_END2END_TEST(CoreEnd2endTests, DISABLED_ServerFilterChannelInitFails) {
   SKIP_IF_V3();
-  SKIP_IF_CORE_CONFIGURATION_RESET_DISABLED();
   RegisterFilter(GRPC_SERVER_CHANNEL);
   InitClient(ChannelArgs());
-  InitServer(ChannelArgs().Set("channel_init_fails", true));
+  InitServer(DefaultServerArgs().Set("channel_init_fails", true));
   auto c = NewClientCall("/foo").Timeout(Duration::Seconds(5)).Create();
   IncomingStatusOnClient server_status;
   IncomingMetadata server_initial_metadata;
@@ -122,7 +121,6 @@ CORE_END2END_TEST(CoreEnd2endTests, DISABLED_ServerFilterChannelInitFails) {
 CORE_END2END_TEST(CoreEnd2endTests, ServerFilterCallInitFails) {
   SKIP_IF_FUZZING();
   SKIP_IF_V3();
-  SKIP_IF_CORE_CONFIGURATION_RESET_DISABLED();
 
   RegisterFilter(GRPC_SERVER_CHANNEL);
   auto c = NewClientCall("/foo").Timeout(Duration::Seconds(5)).Create();
@@ -143,10 +141,9 @@ CORE_END2END_TEST(CoreEnd2endTests, ServerFilterCallInitFails) {
 
 CORE_END2END_TEST(CoreEnd2endTests, DISABLED_ClientFilterChannelInitFails) {
   SKIP_IF_V3();
-  SKIP_IF_CORE_CONFIGURATION_RESET_DISABLED();
   RegisterFilter(GRPC_CLIENT_CHANNEL);
   RegisterFilter(GRPC_CLIENT_DIRECT_CHANNEL);
-  InitServer(ChannelArgs());
+  InitServer(DefaultServerArgs());
   InitClient(ChannelArgs().Set("channel_init_fails", true));
   auto c = NewClientCall("/foo").Timeout(Duration::Seconds(5)).Create();
   IncomingStatusOnClient server_status;
@@ -165,7 +162,6 @@ CORE_END2END_TEST(CoreEnd2endTests, DISABLED_ClientFilterChannelInitFails) {
 CORE_END2END_TEST(CoreEnd2endTests, ClientFilterCallInitFails) {
   SKIP_IF_V3();
   SKIP_IF_FUZZING();
-  SKIP_IF_CORE_CONFIGURATION_RESET_DISABLED();
   RegisterFilter(GRPC_CLIENT_CHANNEL);
   RegisterFilter(GRPC_CLIENT_DIRECT_CHANNEL);
   auto c = NewClientCall("/foo").Timeout(Duration::Seconds(5)).Create();
@@ -187,9 +183,8 @@ CORE_END2END_TEST(CoreEnd2endTests, ClientFilterCallInitFails) {
 CORE_END2END_TEST(CoreClientChannelTests,
                   DISABLED_SubchannelFilterChannelInitFails) {
   SKIP_IF_V3();
-  SKIP_IF_CORE_CONFIGURATION_RESET_DISABLED();
   RegisterFilter(GRPC_CLIENT_SUBCHANNEL);
-  InitServer(ChannelArgs());
+  InitServer(DefaultServerArgs());
   InitClient(ChannelArgs().Set("channel_init_fails", true));
   auto c = NewClientCall("/foo").Timeout(Duration::Seconds(5)).Create();
   IncomingStatusOnClient server_status;
@@ -224,7 +219,6 @@ CORE_END2END_TEST(CoreClientChannelTests,
 
 CORE_END2END_TEST(CoreClientChannelTests, SubchannelFilterCallInitFails) {
   SKIP_IF_V3();
-  SKIP_IF_CORE_CONFIGURATION_RESET_DISABLED();
   RegisterFilter(GRPC_CLIENT_SUBCHANNEL);
   auto c = NewClientCall("/foo").Timeout(Duration::Seconds(5)).Create();
   IncomingStatusOnClient server_status;
