@@ -17,8 +17,8 @@
 #include <grpc/impl/channel_arg_names.h>
 
 #include <memory>
+#include <optional>
 
-#include "absl/types/optional.h"
 #include "src/core/ext/transport/chttp2/transport/internal.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/util/time.h"
@@ -29,11 +29,12 @@ namespace {
 
 // Tests that we can unref a call after the first attempt starts but
 // before any ops complete.  This should not cause a memory leak.
-CORE_END2END_TEST(RetryTest, RetryCancelAfterFirstAttemptStarts) {
+CORE_END2END_TEST(RetryTests, RetryCancelAfterFirstAttemptStarts) {
+  if (!IsRetryInCallv3Enabled()) SKIP_IF_V3();
   // This is a workaround for the flakiness that if the server ever enters
   // GracefulShutdown for whatever reason while the client has already been
   // shutdown, the test would not timeout and fail.
-  InitServer(ChannelArgs().Set(GRPC_ARG_PING_TIMEOUT_MS, 4000));
+  InitServer(DefaultServerArgs());
   InitClient(ChannelArgs().Set(
       GRPC_ARG_SERVICE_CONFIG,
       "{\n"
@@ -50,7 +51,7 @@ CORE_END2END_TEST(RetryTest, RetryCancelAfterFirstAttemptStarts) {
       "    }\n"
       "  } ]\n"
       "}"));
-  absl::optional<Call> c =
+  std::optional<Call> c =
       NewClientCall("/service/method").Timeout(Duration::Seconds(6)).Create();
   // Client starts send ops.
   c->NewBatch(1)
