@@ -19,31 +19,26 @@
 #include "src/core/lib/iomgr/resolve_address.h"
 
 #include <address_sorting/address_sorting.h>
-#include <gmock/gmock.h>
 #include <grpc/grpc.h>
 #include <grpc/support/alloc.h>
 #include <grpc/support/sync.h>
 #include <grpc/support/time.h>
-#include <gtest/gtest.h>
 #include <string.h>
 
 #include "absl/functional/bind_front.h"
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/strings/match.h"
-#include "src/core/lib/config/config_vars.h"
-#include "src/core/lib/iomgr/executor.h"
-#include "src/core/lib/iomgr/iomgr.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
+#include "src/core/config/config_vars.h"
+#include "src/core/lib/event_engine/shim.h"
 #include "src/core/lib/iomgr/pollset.h"
 #include "src/core/resolver/dns/c_ares/grpc_ares_wrapper.h"
-#include "src/core/util/crash.h"
-#include "src/core/util/string.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/sync.h"
 #include "src/core/util/time.h"
-#include "test/core/test_util/cmdline.h"
 #include "test/core/test_util/fake_udp_and_tcp_server.h"
 #include "test/core/test_util/test_config.h"
-#include "test/cpp/util/test_config.h"
 
 namespace {
 
@@ -164,6 +159,21 @@ class ResolveAddressTest : public ::testing::Test {
 
   grpc_pollset_set* pollset_set() const { return pollset_set_; }
 
+ protected:
+  void SetUp() override {
+    if (grpc_core::IsEventEngineForAllOtherEndpointsEnabled() &&
+        !grpc_event_engine::experimental::
+            EventEngineExperimentDisabledForPython()) {
+      GTEST_SKIP()
+          << "Skipping all legacy ResolveAddress tests. The "
+             "event_engine_for_all_other_endpoints experiment is enabled, so "
+             "the grpc_core::GetDNSResolver() API is not in use. Further, the "
+             "experiment replaces iomgr grpc_fds with minimal implementations. "
+             "The legacy resolvers use the grpc_fd APIs directly, so these "
+             "tests would fail.";
+    }
+  }
+
  private:
   static void DoNothing(void* /*arg*/, grpc_error_handle /*error*/) {}
 
@@ -499,6 +509,32 @@ TEST_F(ResolveAddressTest, DeleteInterestedPartiesAfterCancellation) {
   PollPollsetUntilRequestDone();
 }
 
+TEST_F(ResolveAddressTest, StressTestTargetNameDeletion) {
+  // The Lookup APIs take a string_view name to resolve. This regression test
+  // attempts to catch bad implementations that rely on that string_view's
+  // source string to be alive after the function returns.
+  constexpr size_t kIterations = 100;
+  auto resolver = grpc_core::GetDNSResolver();
+  std::atomic<size_t> resolved_count{0};
+  for (size_t i = 0; i < kIterations; i++) {
+    grpc_core::ExecCtx exec_ctx;
+    // Creating target on the heap, to try to delete it before resolution
+    // completes.
+    auto* target = new std::string("arst");
+    resolver->LookupHostname(
+        [&resolved_count](
+            absl::StatusOr<std::vector<grpc_resolved_address>> /* result */) {
+          ++resolved_count;
+        },
+        *target, "8080", grpc_core::Duration::Milliseconds(10), pollset_set(),
+        "");
+    delete target;
+  }
+  while (resolved_count.load() != kIterations) {
+    absl::SleepFor(absl::Milliseconds(10));
+  }
+}
+
 TEST_F(ResolveAddressTest, NativeResolverCannotLookupSRVRecords) {
   if (absl::string_view(g_resolver_type) == "ares") {
     GTEST_SKIP() << "this test is only for native resolvers";
@@ -534,6 +570,11 @@ TEST_F(ResolveAddressTest, NativeResolverCannotLookupTXTRecords) {
 }
 
 int main(int argc, char** argv) {
+  if (grpc_core::IsPollsetAlternativeEnabled()) {
+    LOG(WARNING) << "iomgr resolver tests are disabled since the pollset "
+                    "alternative experiment breaks some iomgr APIs";
+    return 0;
+  }
   // Configure the DNS resolver (c-ares vs. native) based on the
   // name of the binary. TODO(apolcyn): is there a way to pass command
   // line flags to a gtest that it works in all of our test environments?
@@ -542,7 +583,7 @@ int main(int argc, char** argv) {
   } else if (absl::StrContains(std::string(argv[0]), "using_ares_resolver")) {
     g_resolver_type = "ares";
   } else {
-    CHECK(0);
+    GRPC_CHECK(0);
   }
   grpc_core::ConfigVars::Overrides overrides;
   overrides.dns_resolver = g_resolver_type;
