@@ -14,18 +14,20 @@
 
 #include "src/core/lib/surface/channel_init.h"
 
+#include <algorithm>
 #include <map>
 #include <memory>
 #include <string>
+#include <utility>
 
 #include "absl/strings/string_view.h"
 #include "gtest/gtest.h"
+#include "src/core/call/call_arena_allocator.h"
 #include "src/core/lib/channel/channel_stack.h"
 #include "src/core/lib/channel/channel_stack_builder_impl.h"
 #include "src/core/lib/channel/promise_based_filter.h"
 #include "src/core/lib/resource_quota/resource_quota.h"
 #include "src/core/lib/surface/channel_stack_type.h"
-#include "src/core/lib/transport/call_arena_allocator.h"
 #include "test/core/test_util/test_config.h"
 
 namespace grpc_core {
@@ -48,6 +50,17 @@ const grpc_channel_filter* FilterNamed(const char* name) {
       .first->second;
 }
 
+auto RemoveFilterNamed(std::string name) {
+  return [name](ChannelStackBuilder& builder) {
+    auto* stk = builder.mutable_stack();
+    stk->erase(std::remove_if(stk->begin(), stk->end(),
+                              [name](const grpc_channel_filter* filter) {
+                                return filter->name.name() == name;
+                              }),
+               stk->end());
+  };
+}
+
 std::vector<std::string> GetFilterNames(const ChannelInit& init,
                                         grpc_channel_stack_type type,
                                         const ChannelArgs& args) {
@@ -82,7 +95,7 @@ TEST(ChannelInitTest, OneClientFilter) {
 }
 
 TEST(ChannelInitTest, DefaultLexicalOrdering) {
-  // ChannelInit defaults to lexical ordering in the absense of other
+  // ChannelInit defaults to lexical ordering in the absence of other
   // constraints, to ensure that a stable ordering is produced between builds.
   ChannelInit::Builder b;
   b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("foo"));
@@ -181,6 +194,16 @@ TEST(ChannelInitTest, CanAddBeforeAllOnce) {
             std::vector<std::string>({"foo", "bar", "baz", "aaa"}));
 }
 
+TEST(ChannelInitTest, FloatToTopRespectsBeforeAll) {
+  ChannelInit::Builder b;
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("foo")).BeforeAll();
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("bar"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("baz")).FloatToTop();
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("aaa")).Terminal();
+  EXPECT_EQ(GetFilterNames(b.Build(), GRPC_CLIENT_CHANNEL, ChannelArgs()),
+            std::vector<std::string>({"foo", "baz", "bar", "aaa"}));
+}
+
 TEST(ChannelInitDeathTest, CanAddBeforeAllTwice) {
   GTEST_FLAG_SET(death_test_style, "threadsafe");
   ChannelInit::Builder b;
@@ -268,6 +291,90 @@ TEST(ChannelInitTest, BottomCanComeBeforeTopWithExplicitOrdering) {
             std::vector<std::string>({"b", "c", "terminator"}));
 }
 
+TEST(ChannelInitTest, CanRegisterFusedFilters) {
+  ChannelInit::Builder b;
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter1"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter2"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter3"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter4"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter5"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter6"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter7"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter8"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter9"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("terminal1")).Terminal();
+  b.RegisterFusedFilter(GRPC_CLIENT_CHANNEL,
+                        FilterNamed("Filter4+Filter5+Filter6+Filter7"));
+  b.RegisterFusedFilter(GRPC_CLIENT_CHANNEL,
+                        FilterNamed("Filter2+Filter3+Filter4"));
+  b.RegisterFusedFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter2+Filter3"));
+  EXPECT_EQ(GetFilterNames(b.Build(), GRPC_CLIENT_CHANNEL, ChannelArgs()),
+            std::vector<std::string>({"Filter1", "Filter2+Filter3",
+                                      "Filter4+Filter5+Filter6+Filter7",
+                                      "Filter8", "Filter9", "terminal1"}));
+}
+
+TEST(ChannelInitTest, CanRegisterFusedFiltersWithPostProcessors) {
+  ChannelInit::Builder b;
+  // Register 2 post processors to remove filter 2 and filter 5.
+  b.RegisterPostProcessor(GRPC_CLIENT_CHANNEL,
+                          ChannelInit::PostProcessorSlot::kAuthSubstitution,
+                          RemoveFilterNamed("Filter2"));
+  b.RegisterPostProcessor(
+      GRPC_CLIENT_CHANNEL,
+      ChannelInit::PostProcessorSlot::kXdsChannelStackModifier,
+      RemoveFilterNamed("Filter5"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter1"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter2"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter3"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter4"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter5"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter6"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter7"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter8"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter9"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("terminal1")).Terminal();
+  b.RegisterFusedFilter(GRPC_CLIENT_CHANNEL,
+                        FilterNamed("Filter4+Filter5+Filter6+Filter7"));
+  b.RegisterFusedFilter(GRPC_CLIENT_CHANNEL,
+                        FilterNamed("Filter4+Filter6+Filter7"));
+  b.RegisterFusedFilter(GRPC_CLIENT_CHANNEL,
+                        FilterNamed("Filter2+Filter3+Filter4"));
+  b.RegisterFusedFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter2+Filter3"));
+  // Filter2 is removed by the post processor, so it should not be present in
+  // the fused filters. Filter5 is removed by the post processor, so the fused
+  // filter that contains it should not be present but the fusion
+  // "Filter4+Filter6+Filter7" should be included.
+  EXPECT_EQ(
+      GetFilterNames(b.Build(), GRPC_CLIENT_CHANNEL, ChannelArgs()),
+      std::vector<std::string>({"Filter1", "Filter3", "Filter4+Filter6+Filter7",
+                                "Filter8", "Filter9", "terminal1"}));
+}
+
+TEST(ChannelInitTest, PredicateMatchingWithFusedFilters) {
+  ChannelInit::Builder b;
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter1"))
+      .IfChannelArg("filter1", true);
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter2"))
+      .IfChannelArg("filter2", true);
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter3"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter4"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter5"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("Filter6"));
+  b.RegisterFilter(GRPC_CLIENT_CHANNEL, FilterNamed("terminal1")).Terminal();
+  b.RegisterFusedFilter(GRPC_CLIENT_CHANNEL,
+                        FilterNamed("Filter1+Filter2+Filter3+Filter4+Filter5"));
+  b.RegisterFusedFilter(GRPC_CLIENT_CHANNEL,
+                        FilterNamed("Filter2+Filter3+Filter4+Filter5"));
+  b.RegisterFusedFilter(GRPC_CLIENT_CHANNEL,
+                        FilterNamed("Filter3+Filter4+Filter5"));
+  EXPECT_EQ(
+      GetFilterNames(b.Build(), GRPC_CLIENT_CHANNEL,
+                     ChannelArgs().Set("filter1", false).Set("filter2", true)),
+      std::vector<std::string>(
+          {"Filter2+Filter3+Filter4+Filter5", "Filter6", "terminal1"}));
+}
+
 class TestFilter1 {
  public:
   explicit TestFilter1(int* p) : p_(p) {}
