@@ -31,7 +31,6 @@
 #include <memory>
 #include <thread>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/memory/memory.h"
 #include "absl/strings/str_cat.h"
@@ -41,6 +40,7 @@
 #include "src/core/lib/iomgr/port.h"
 #include "src/core/util/crash.h"
 #include "src/core/util/debug_location.h"
+#include "src/core/util/grpc_check.h"
 #include "src/proto/grpc/health/v1/health.grpc.pb.h"
 #include "src/proto/grpc/testing/duplicate/echo_duplicate.grpc.pb.h"
 #include "src/proto/grpc/testing/echo.grpc.pb.h"
@@ -54,7 +54,7 @@
 #include "src/core/lib/iomgr/ev_posix.h"
 #endif  // GRPC_POSIX_SOCKET_EV
 
-#include <gtest/gtest.h>
+#include "gtest/gtest.h"
 
 using grpc::testing::EchoRequest;
 using grpc::testing::EchoResponse;
@@ -128,7 +128,7 @@ class Verifier {
   // This version of Verify allows optionally ignoring the
   // outcome of the expectation
   void Verify(CompletionQueue* cq, bool ignore_ok) {
-    CHECK(!expectations_.empty() || !maybe_expectations_.empty());
+    GRPC_CHECK(!expectations_.empty() || !maybe_expectations_.empty());
     while (!expectations_.empty()) {
       Next(cq, ignore_ok);
     }
@@ -186,20 +186,18 @@ class Verifier {
         EXPECT_EQ(it->second.ok, ok) << it->second.ToString(it->first);
       }
       expectations_.erase(it);
-    } else {
-      auto it2 = maybe_expectations_.find(got_tag);
-      if (it2 != maybe_expectations_.end()) {
-        if (it2->second.seen != nullptr) {
-          EXPECT_FALSE(*it2->second.seen);
-          *it2->second.seen = true;
-        }
-        if (!ignore_ok) {
-          EXPECT_EQ(it2->second.ok, ok) << it->second.ToString(it->first);
-        }
-        maybe_expectations_.erase(it2);
-      } else {
-        grpc_core::Crash(absl::StrFormat("Unexpected tag: %p", got_tag));
+    } else if (auto it2 = maybe_expectations_.find(got_tag);
+               it2 != maybe_expectations_.end()) {
+      if (it2->second.seen != nullptr) {
+        EXPECT_FALSE(*it2->second.seen);
+        *it2->second.seen = true;
       }
+      if (!ignore_ok) {
+        EXPECT_EQ(it2->second.ok, ok) << it->second.ToString(it->first);
+      }
+      maybe_expectations_.erase(it2);
+    } else {
+      grpc_core::Crash(absl::StrFormat("Unexpected tag: %p", got_tag));
     }
   }
 
@@ -1476,7 +1474,7 @@ class AsyncEnd2endServerTryCancelTest : public AsyncEnd2endTest {
       // just added
       int got_tag = verif.Expect(tag_idx, expected_server_cq_result)
                         .Next(cq_.get(), ignore_cq_result);
-      CHECK((got_tag == tag_idx) || (got_tag == 11 && want_done_tag));
+      GRPC_CHECK((got_tag == tag_idx) || (got_tag == 11 && want_done_tag));
       if (got_tag == 11) {
         EXPECT_TRUE(srv_ctx.IsCancelled());
         want_done_tag = false;
@@ -1626,7 +1624,7 @@ class AsyncEnd2endServerTryCancelTest : public AsyncEnd2endTest {
       // just added
       int got_tag = verif.Expect(tag_idx, expected_cq_result)
                         .Next(cq_.get(), ignore_cq_result);
-      CHECK((got_tag == tag_idx) || (got_tag == 11 && want_done_tag));
+      GRPC_CHECK((got_tag == tag_idx) || (got_tag == 11 && want_done_tag));
       if (got_tag == 11) {
         EXPECT_TRUE(srv_ctx.IsCancelled());
         want_done_tag = false;
@@ -1738,7 +1736,7 @@ class AsyncEnd2endServerTryCancelTest : public AsyncEnd2endTest {
 
       do {
         got_tag = verif.Next(cq_.get(), ignore_cq_result);
-        CHECK(((got_tag == 3) && !tag_3_done) || (got_tag == 11));
+        GRPC_CHECK(((got_tag == 3) && !tag_3_done) || (got_tag == 11));
         if (got_tag == 3) {
           tag_3_done = true;
         }
@@ -1766,16 +1764,17 @@ class AsyncEnd2endServerTryCancelTest : public AsyncEnd2endTest {
     verif.Expect(4, expected_cq_result);
     got_tag = tag_3_done ? 3 : verif.Next(cq_.get(), ignore_cq_result);
     got_tag2 = verif.Next(cq_.get(), ignore_cq_result);
-    CHECK((got_tag == 3) || (got_tag == 4) || (got_tag == 11 && want_done_tag));
-    CHECK((got_tag2 == 3) || (got_tag2 == 4) ||
-          (got_tag2 == 11 && want_done_tag));
+    GRPC_CHECK((got_tag == 3) || (got_tag == 4) ||
+               (got_tag == 11 && want_done_tag));
+    GRPC_CHECK((got_tag2 == 3) || (got_tag2 == 4) ||
+               (got_tag2 == 11 && want_done_tag));
     // If we get 3 and 4, we don't need to wait for 11, but if
     // we get 11, we should also clear 3 and 4
     if (got_tag + got_tag2 != 7) {
       EXPECT_TRUE(srv_ctx.IsCancelled());
       want_done_tag = false;
       got_tag = verif.Next(cq_.get(), ignore_cq_result);
-      CHECK((got_tag == 3) || (got_tag == 4));
+      GRPC_CHECK((got_tag == 3) || (got_tag == 4));
     }
 
     send_response.set_message("Pong");
@@ -1786,16 +1785,17 @@ class AsyncEnd2endServerTryCancelTest : public AsyncEnd2endTest {
     verif.Expect(6, expected_cq_result);
     got_tag = verif.Next(cq_.get(), ignore_cq_result);
     got_tag2 = verif.Next(cq_.get(), ignore_cq_result);
-    CHECK((got_tag == 5) || (got_tag == 6) || (got_tag == 11 && want_done_tag));
-    CHECK((got_tag2 == 5) || (got_tag2 == 6) ||
-          (got_tag2 == 11 && want_done_tag));
+    GRPC_CHECK((got_tag == 5) || (got_tag == 6) ||
+               (got_tag == 11 && want_done_tag));
+    GRPC_CHECK((got_tag2 == 5) || (got_tag2 == 6) ||
+               (got_tag2 == 11 && want_done_tag));
     // If we get 5 and 6, we don't need to wait for 11, but if
     // we get 11, we should also clear 5 and 6
     if (got_tag + got_tag2 != 11) {
       EXPECT_TRUE(srv_ctx.IsCancelled());
       want_done_tag = false;
       got_tag = verif.Next(cq_.get(), ignore_cq_result);
-      CHECK((got_tag == 5) || (got_tag == 6));
+      GRPC_CHECK((got_tag == 5) || (got_tag == 6));
     }
 
     // This is expected to succeed in all cases
@@ -1806,7 +1806,7 @@ class AsyncEnd2endServerTryCancelTest : public AsyncEnd2endTest {
     bool ignore_cq_wd_result =
         ignore_cq_result || (server_try_cancel == CANCEL_BEFORE_PROCESSING);
     got_tag = verif.Next(cq_.get(), ignore_cq_wd_result);
-    CHECK((got_tag == 7) || (got_tag == 11 && want_done_tag));
+    GRPC_CHECK((got_tag == 7) || (got_tag == 11 && want_done_tag));
     if (got_tag == 11) {
       EXPECT_TRUE(srv_ctx.IsCancelled());
       want_done_tag = false;
@@ -1821,7 +1821,7 @@ class AsyncEnd2endServerTryCancelTest : public AsyncEnd2endTest {
     srv_stream.Read(&recv_request, tag(8));
     verif.Expect(8, false);
     got_tag = verif.Next(cq_.get(), ignore_cq_result);
-    CHECK((got_tag == 8) || (got_tag == 11 && want_done_tag));
+    GRPC_CHECK((got_tag == 8) || (got_tag == 11 && want_done_tag));
     if (got_tag == 11) {
       EXPECT_TRUE(srv_ctx.IsCancelled());
       want_done_tag = false;
@@ -1916,7 +1916,7 @@ std::vector<TestScenario> CreateTestScenarios(bool /*test_secure*/,
   for (auto sec = sec_list.begin(); sec != sec_list.end(); sec++) {
     credentials_types.push_back(*sec);
   }
-  CHECK(!credentials_types.empty());
+  GRPC_CHECK(!credentials_types.empty());
 
   messages.push_back("Hello");
   if (test_message_size_limit) {
