@@ -16,7 +16,6 @@
 #ifndef GRPC_TEST_CPP_END2END_XDS_XDS_END2END_TEST_LIB_H
 #define GRPC_TEST_CPP_END2END_XDS_XDS_END2END_TEST_LIB_H
 
-#include <gmock/gmock.h>
 #include <grpc/grpc.h>
 #include <grpc/grpc_security.h>
 #include <grpcpp/channel.h>
@@ -24,28 +23,31 @@
 #include <grpcpp/ext/call_metric_recorder.h>
 #include <grpcpp/ext/server_metric_recorder.h>
 #include <grpcpp/xds_server_builder.h>
-#include <gtest/gtest.h>
 
 #include <memory>
+#include <optional>
 #include <set>
 #include <string>
 #include <thread>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/status/statusor.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/string_view.h"
-#include "absl/types/optional.h"
 #include "envoy/config/rbac/v3/rbac.pb.h"
 #include "envoy/extensions/filters/http/rbac/v3/rbac.pb.h"
 #include "envoy/extensions/filters/network/http_connection_manager/v3/http_connection_manager.pb.h"
-#include "src/core/lib/security/credentials/fake/fake_credentials.h"
-#include "src/core/lib/security/security_connector/ssl_utils.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
+#include "src/core/credentials/transport/fake/fake_credentials.h"
+#include "src/core/credentials/transport/tls/ssl_utils.h"
+#include "src/core/lib/event_engine/default_event_engine.h"
+#include "src/core/util/grpc_check.h"
 #include "src/cpp/server/secure_server_credentials.h"
 #include "src/proto/grpc/testing/echo.pb.h"
 #include "test/core/test_util/port.h"
+#include "test/core/test_util/resolve_localhost_ip46.h"
 #include "test/cpp/end2end/counted_service.h"
 #include "test/cpp/end2end/test_service_impl.h"
 #include "test/cpp/end2end/xds/xds_server.h"
@@ -201,6 +203,9 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
   static const char kCaCertPath[];
   static const char kServerCertPath[];
   static const char kServerKeyPath[];
+  static const char kSpiffeCaCertPath[];
+  static const char kSpiffeServerCertPath[];
+  static const char kSpiffeServerKeyPath[];
 
   // Message used in EchoRequest to the backend.
   static const char kRequestMessage[];
@@ -209,6 +214,18 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
   class ServerThread {
    public:
     // A status notifier for xDS-enabled servers.
+    //
+    // TODO(yashykt): This notifier records the most recent state seen
+    // for every URI and then lets the caller wait until the status for
+    // that URI is the expected one.  If we are expecting an update that
+    // has the same status as the previous one, then we really have no
+    // way of knowing whether the second update has actually been sent.
+    // A better approach here would be to queue the updates received by
+    // the notifier and then have a method to get the next update from
+    // the queue, if any.
+    // Also, we should change the callers to check not just the status
+    // but also the corresponding error message, so that we can verify
+    // that we're emitting useful error messages for our users.
     class XdsServingStatusNotifier
         : public grpc::XdsServerServingStatusNotifierInterface {
      public:
@@ -234,7 +251,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
     virtual ~ServerThread() {
       // Shutdown should be called manually. Shutdown calls virtual methods and
       // can't be called from the base class destructor.
-      CHECK(!running_);
+      GRPC_CHECK(!running_);
     }
 
     void Start();
@@ -246,6 +263,13 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
 
     XdsServingStatusNotifier* notifier() { return &notifier_; }
 
+    GRPC_MUST_USE_RESULT bool WaitOnServingStatusChange(
+        grpc::StatusCode expected_status,
+        absl::Duration timeout = absl::Seconds(10)) {
+      return notifier_.WaitOnServingStatusChange(
+          grpc_core::LocalIpAndPort(port_), expected_status, timeout);
+    }
+
     void set_allow_put_requests(bool allow_put_requests) {
       allow_put_requests_ = allow_put_requests;
     }
@@ -314,12 +338,12 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
             recorder->RecordApplicationUtilizationMetric(
                 request_metrics.application_utilization());
           }
-          for (const auto& p : request_metrics.named_metrics()) {
-            char* key = static_cast<char*>(
-                grpc_call_arena_alloc(context->c_call(), p.first.size() + 1));
-            strncpy(key, p.first.data(), p.first.size());
-            key[p.first.size()] = '\0';
-            recorder->RecordNamedMetric(key, p.second);
+          for (const auto& [key, value] : request_metrics.named_metrics()) {
+            char* key_copy = static_cast<char*>(
+                grpc_call_arena_alloc(context->c_call(), key.size() + 1));
+            strncpy(key_copy, key.data(), key.size());
+            key_copy[key.size()] = '\0';
+            recorder->RecordNamedMetric(key_copy, value);
           }
         }
         const auto status = TestMultipleServiceImpl<RpcService>::Echo(
@@ -487,7 +511,8 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
       ::envoy::config::core::v3::HealthStatus health_status =
           ::envoy::config::core::v3::HealthStatus::UNKNOWN,
       int lb_weight = 1, std::vector<size_t> additional_backend_indexes = {},
-      absl::string_view hostname = "") {
+      absl::string_view hostname = "",
+      const std::map<std::string, std::string /*JSON*/>& metadata = {}) {
     std::vector<int> additional_ports;
     additional_ports.reserve(additional_backend_indexes.size());
     for (size_t idx : additional_backend_indexes) {
@@ -495,7 +520,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
     }
     return EdsResourceArgs::Endpoint(backends_[backend_idx]->port(),
                                      health_status, lb_weight, additional_ports,
-                                     hostname);
+                                     hostname, metadata);
   }
 
   // Creates a vector of endpoints for a specified range of backends,
@@ -578,7 +603,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
   // and channel args for the XdsClient.  Then calls ResetStub().
   // All tests must call this exactly once at the start of the test.
   // If credentials is null, fake credentials will be used.
-  void InitClient(absl::optional<XdsBootstrapBuilder> builder = absl::nullopt,
+  void InitClient(std::optional<XdsBootstrapBuilder> builder = std::nullopt,
                   std::string lb_expected_authority = "",
                   int xds_resource_does_not_exist_timeout_ms = 0,
                   std::string balancer_authority_override = "",
@@ -621,7 +646,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
     int client_cancel_after_us = 0;
     bool skip_cancelled_check = false;
     StatusCode server_expected_error = StatusCode::OK;
-    absl::optional<xds::data::orca::v3::OrcaLoadReport> backend_metrics;
+    std::optional<xds::data::orca::v3::OrcaLoadReport> backend_metrics;
     bool server_notify_client_when_started = false;
     bool echo_host_from_authority_header = false;
     bool echo_metadata_initially = false;
@@ -685,7 +710,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
     }
 
     RpcOptions& set_backend_metrics(
-        absl::optional<xds::data::orca::v3::OrcaLoadReport> metrics) {
+        std::optional<xds::data::orca::v3::OrcaLoadReport> metrics) {
       backend_metrics = std::move(metrics);
       return *this;
     }
@@ -757,6 +782,14 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
                            absl::string_view expected_message_regex,
                            const RpcOptions& rpc_options = RpcOptions());
 
+  // Sends RPCs until either a timeout or an RPC fail, in which case the
+  // failure must match the specified status and message regex.
+  void SendRpcsUntilFailure(const grpc_core::DebugLocation& debug_location,
+                            StatusCode expected_status,
+                            absl::string_view expected_message_regex,
+                            int timeout_ms = 15000,
+                            const RpcOptions& rpc_options = RpcOptions());
+
   // Sends num_rpcs RPCs, counting how many of them fail with a message
   // matching the specified expected_message_prefix.
   // Any failure with a non-matching status or message is a test failure.
@@ -765,10 +798,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
       StatusCode expected_status, absl::string_view expected_message_prefix,
       const RpcOptions& rpc_options = RpcOptions());
 
-  // A class for running a long-running RPC in its own thread.
-  // TODO(roth): Maybe consolidate this and SendConcurrentRpcs()
-  // somehow?  LongRunningRpc has a cleaner API, but SendConcurrentRpcs()
-  // uses the callback API, which is probably better.
+  // A class for running a long-running RPC using the callback API.
   class LongRunningRpc {
    public:
     // Starts the RPC.
@@ -784,12 +814,16 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
     Status GetStatus();
 
    private:
-    std::thread sender_thread_;
+    EchoRequest request_;
+    EchoResponse response_;
     ClientContext context_;
-    Status status_;
+    grpc_core::Mutex mu_;
+    grpc_core::CondVar cv_;
+    std::optional<Status> status_ ABSL_GUARDED_BY(&mu_);
   };
 
   // Starts a set of concurrent RPCs.
+  // TODO(roth): Change this to use LongRunningRpc.
   struct ConcurrentRpc {
     ClientContext context;
     Status status;
@@ -853,14 +887,21 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
   // xDS server, or until a timeout expires.
 
   // Sends RPCs until get_state() returns a response.
-  absl::optional<AdsServiceImpl::ResponseState> WaitForNack(
+  // TODO(roth): Does this actually need to send RPCs, or can it just
+  // use a condition variable to wait?  I suspect that we need to be
+  // sending RPCs for polling reasons, but that should go away when we
+  // finish the EventEngine migration.  Once that's done, try changing
+  // this to not send RPCs.
+  // Also, consider refactoring to also support waiting for ACKs, since
+  // there are several use-cases where tests are doing that.
+  std::optional<AdsServiceImpl::ResponseState> WaitForNack(
       const grpc_core::DebugLocation& debug_location,
-      std::function<absl::optional<AdsServiceImpl::ResponseState>()> get_state,
+      std::function<std::optional<AdsServiceImpl::ResponseState>()> get_state,
       const RpcOptions& rpc_options = RpcOptions(),
       StatusCode expected_status = StatusCode::UNAVAILABLE);
 
   // Sends RPCs until an LDS NACK is seen.
-  absl::optional<AdsServiceImpl::ResponseState> WaitForLdsNack(
+  std::optional<AdsServiceImpl::ResponseState> WaitForLdsNack(
       const grpc_core::DebugLocation& debug_location,
       const RpcOptions& rpc_options = RpcOptions(),
       StatusCode expected_status = StatusCode::UNAVAILABLE) {
@@ -871,7 +912,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
   }
 
   // Sends RPCs until an RDS NACK is seen.
-  absl::optional<AdsServiceImpl::ResponseState> WaitForRdsNack(
+  std::optional<AdsServiceImpl::ResponseState> WaitForRdsNack(
       const grpc_core::DebugLocation& debug_location,
       const RpcOptions& rpc_options = RpcOptions(),
       StatusCode expected_status = StatusCode::UNAVAILABLE) {
@@ -882,7 +923,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
   }
 
   // Sends RPCs until a CDS NACK is seen.
-  absl::optional<AdsServiceImpl::ResponseState> WaitForCdsNack(
+  std::optional<AdsServiceImpl::ResponseState> WaitForCdsNack(
       const grpc_core::DebugLocation& debug_location,
       const RpcOptions& rpc_options = RpcOptions(),
       StatusCode expected_status = StatusCode::UNAVAILABLE) {
@@ -893,7 +934,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
   }
 
   // Sends RPCs until an EDS NACK is seen.
-  absl::optional<AdsServiceImpl::ResponseState> WaitForEdsNack(
+  std::optional<AdsServiceImpl::ResponseState> WaitForEdsNack(
       const grpc_core::DebugLocation& debug_location,
       const RpcOptions& rpc_options = RpcOptions()) {
     return WaitForNack(
@@ -904,7 +945,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
 
   // Convenient front-end to wait for RouteConfiguration to be NACKed,
   // regardless of whether it's sent in LDS or RDS.
-  absl::optional<AdsServiceImpl::ResponseState> WaitForRouteConfigNack(
+  std::optional<AdsServiceImpl::ResponseState> WaitForRouteConfigNack(
       const grpc_core::DebugLocation& debug_location,
       const RpcOptions& rpc_options = RpcOptions(),
       StatusCode expected_status = StatusCode::UNAVAILABLE) {
@@ -916,7 +957,7 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
 
   // Convenient front-end for accessing xDS response state for a
   // RouteConfiguration, regardless of whether it's sent in LDS or RDS.
-  absl::optional<AdsServiceImpl::ResponseState> RouteConfigurationResponseState(
+  std::optional<AdsServiceImpl::ResponseState> RouteConfigurationResponseState(
       BalancerServerThread* balancer) const {
     AdsServiceImpl* ads_service = balancer->ads_service();
     if (GetParam().enable_rds_testing()) {
@@ -962,8 +1003,8 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
   // use a uniform distribution instead. We need a better estimate of how many
   // RPCs are needed with what error tolerance.
   static size_t ComputeIdealNumRpcs(double p, double error_tolerance) {
-    CHECK_GE(p, 0);
-    CHECK_LE(p, 1);
+    GRPC_CHECK_GE(p, 0);
+    GRPC_CHECK_LE(p, 1);
     size_t num_rpcs =
         ceil(p * (1 - p) * 5.00 * 5.00 / error_tolerance / error_tolerance);
     num_rpcs += 1000;  // Add 1K as a buffer to avoid flakiness.
@@ -974,7 +1015,9 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
 
   // Returns a regex that can be matched against an RPC failure status
   // message for a connection failure.
-  static std::string MakeConnectionFailureRegex(absl::string_view prefix);
+  static std::string MakeConnectionFailureRegex(
+      absl::string_view prefix,
+      absl::string_view resolution_note = "xDS node ID:xds_end2end_test");
 
   // Returns a regex that can be matched against an RPC failure status
   // message for a Tls handshake failure.
@@ -989,14 +1032,36 @@ class XdsEnd2endTest : public ::testing::TestWithParam<XdsTestType>,
   static std::vector<experimental::IdentityKeyCertPair>
   MakeIdentityKeyCertPairForTlsCreds();
 
+  // Internal helper function for creating TLS and mTLS creds.
+  // Not intended to be used by tests.
+  static std::vector<experimental::IdentityKeyCertPair>
+  MakeIdentityKeyCertPairForSpiffeMtlsCreds();
+
   // Returns XdsCredentials with mTLS fallback creds.
   static std::shared_ptr<ChannelCredentials> CreateXdsChannelCredentials();
   static std::shared_ptr<ChannelCredentials> CreateTlsChannelCredentials();
+  static std::shared_ptr<ChannelCredentials>
+  CreateSpiffeXdsChannelCredentials();
+  static std::shared_ptr<ChannelCredentials>
+  CreateSpiffeTlsChannelCredentials();
 
   // Creates various types of server credentials.
   static std::shared_ptr<ServerCredentials> CreateFakeServerCredentials();
   static std::shared_ptr<ServerCredentials> CreateMtlsServerCredentials();
   static std::shared_ptr<ServerCredentials> CreateTlsServerCredentials();
+  static std::shared_ptr<ServerCredentials> CreateMtlsSpiffeServerCredentials();
+
+  // event_engine_scope_ always has to be at the top of the list to make sure
+  // that all other objects are destroyed before this and other event engine
+  // refs are released.
+  // We are using DefaultEventEngineScope to make sure that all work from the
+  // current test is done before the next test starts. Without this, we run into
+  // errors such as https://github.com/grpc/grpc/issues/38588. Note that we are
+  // using all refs to current event engine going down to 0 as a proxy for
+  // checking that all work from the current test is done, but this is not a
+  // guaranteed way since there might still be threads that are not using event
+  // engine but are still accessing/modifying the system state.
+  grpc_event_engine::experimental::DefaultEventEngineScope scoped_event_engine_;
 
   std::unique_ptr<BalancerServerThread> balancer_;
 
